@@ -193,6 +193,30 @@ class BaseAttr:
         self.data = data
 
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        解析消息
+
+        Returns:
+            self.data['name'] 物体名称
+
+            self.data['position'] 物体世界坐标
+
+            self.data['rotation'] 物体世界欧拉角
+
+            self.data['quaternion'] 物体世界四元数
+
+            self.data['local_position'] 物体局部坐标
+
+            self.data['local_rotation'] 物体局部欧拉角
+
+            self.data['local_quaternion'] 物体局部四元数
+
+            self.data['local_to_world_matrix'] 物体局部坐标转世界坐标矩阵
+
+            self.data['result_local_point'] 物体局部坐标转世界坐标结果
+
+            self.data['result_world_point'] 物体世界坐标转局部坐标结果
+        """
         self.data['name'] = msg.read_string()
         self.data['position'] = [msg.read_float32() for _ in range(3)]
         self.data['rotation'] = [msg.read_float32() for _ in range(3)]
