@@ -10,5 +10,11 @@ class ClothAttr(attr.BaseAttr):
     ObiCloth类
     """
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        解析消息
+
+        Returns:
+
+        """
         super().parse_message(msg)
         return self.data
\ No newline at end of file
