@@ -22,6 +22,12 @@ class ColliderAttr(attr.GameObjectAttr):
     具有碰撞体的物体类
     """
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        解析消息
+
+        Returns:
+
+        """
         super().parse_message(msg)
         return self.data
 
