@@ -421,6 +421,44 @@ class ControllerAttr(attr.ColliderAttr):
     机械臂控制器类
     """
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        解析消息
+
+        Returns:
+            self.data['number_of_joints'] 机械臂关节数量
+
+            self.data['positions'] 机械臂节点位置
+
+            self.data['rotations'] 机械臂节点旋转角度
+
+            self.data['quaternion'] 机械臂节点旋转四元数
+
+            self.data['local_positions'] 机械臂节点局部位置
+
+            self.data['local_rotations'] 机械臂节点局部旋转角度
+
+            self.data['local_quaternion'] 机械臂节点局部旋转四元数
+
+            self.data['velocities'] 机械臂节点速度
+
+            self.data['number_of_moveable_joints'] 机械臂活动关节数量
+
+            self.data['joint_positions'] 机械臂关节在自由度空间下位置
+
+            self.data['joint_velocities'] 机械臂关节在自由度空间下速度
+
+            self.data['all_stable'] 机械臂所有关节移动完成
+
+            self.data['move_done'] 机械臂IK移动完成状态
+
+            self.data['rotate_done'] 机械臂IK旋转完成状态
+
+            self.data['gravity_forces'] InverseDynamics抵消重力所需的力
+
+            self.data['coriolis_centrifugal_forces'] InverseDynamics抵消离心力所需的力
+
+            self.data['drive_forces'] InverseDynamics驱动力
+        """
         super().parse_message(msg)
         self.data['number_of_joints'] = msg.read_int32()
         # Position
