@@ -10,6 +10,20 @@ class GraspSimAttr(attr.BaseAttr):
     抓取测试农场仿真类
     """
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        消息解析
+
+        Returns:
+            self.data['done'] 模拟是否完成
+
+            self.data['points'] 抓点列表
+
+            self.data['quaternions'] 抓点对应的四元数列表
+
+            self.data['width'] 抓点对应的抓型宽度列表
+
+            self.data['success'] 抓点对应的抓取结果列表
+        """
         super().parse_message(msg)
         self.data['done'] = msg.read_bool()
         if self.data['done']:
