@@ -53,6 +53,14 @@ class RigidbodyAttr(attr.ColliderAttr):
     刚体类
     """
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        解析消息
+
+        Returns:
+            self.data['velocity'] 刚体速度 Vecter3
+
+            self.data['angular_vel'] 刚体角速度 Vecter3
+        """
         super().parse_message(msg)
         self.data['velocity'] = [msg.read_float32() for _ in range(3)]
         self.data['angular_vel'] = [msg.read_float32() for _ in range(3)]
