@@ -9,5 +9,11 @@ class SoftbodyAttr(attr.BaseAttr):
     ObiSoftbody类
     """
     def parse_message(self, msg: IncomingMessage) -> dict:
+        """
+        解析消息
+
+        Returns:
+
+        """
         super().parse_message(msg)
         return self.data
\ No newline at end of file
